@@ -5,7 +5,7 @@ describe 'cinder::backend::bdd' do
   let(:title) { 'hippo' }
 
   let :params do {
-    :iscsi_ip_address  => '127.0.0.2',
+    :target_ip_address => '127.0.0.2',
     :available_devices => '/dev/sda',
   }
   end
@@ -16,34 +16,41 @@ describe 'cinder::backend::bdd' do
         should contain_cinder_config('hippo/volume_backend_name').with_value('hippo')
         should contain_cinder_config('hippo/volume_driver').with_value('cinder.volume.drivers.block_device.BlockDeviceDriver')
         should contain_cinder_config('hippo/available_devices').with_value('/dev/sda')
-        should contain_cinder_config('hippo/iscsi_helper').with_value('tgtadm')
+        should contain_cinder_config('hippo/target_helper').with_value('tgtadm')
         should contain_cinder_config('hippo/volumes_dir').with_value('/var/lib/cinder/volumes')
-        should contain_cinder_config('hippo/iscsi_ip_address').with_value('127.0.0.2')
+        should contain_cinder_config('hippo/target_ip_address').with_value('127.0.0.2')
         should contain_cinder_config('hippo/volume_group').with_value('<SERVICE DEFAULT>')
-        should contain_cinder_config('hippo/iscsi_protocol').with_value('<SERVICE DEFAULT>')
+        should contain_cinder_config('hippo/target_protocol').with_value('<SERVICE DEFAULT>')
         should contain_cinder_config('hippo/volume_clear').with_value('<SERVICE DEFAULT>')
+        should contain_cinder_config('hippo/backend_availability_zone').with_value('<SERVICE DEFAULT>')
       end
     end
 
     context 'with optional parameters' do
       before :each do
         params.merge!({
-          :iscsi_ip_address  => '10.20.0.2',
-          :available_devices => '/dev/sdb,/dev/sdc',
-          :volumes_dir       => '/var/lib/cinder/bdd-volumes',
-          :volume_clear      => 'zero',
-          :volume_group      => 'cinder',
-          :iscsi_helper      => 'lioadm',
+          :target_ip_address         => '10.20.0.2',
+          :available_devices         => '/dev/sdb,/dev/sdc',
+          :volumes_dir               => '/var/lib/cinder/bdd-volumes',
+          :volume_clear              => 'zero',
+          :volume_group              => 'cinder',
+          :target_helper             => 'lioadm',
+          :manage_volume_type        => true,
+          :backend_availability_zone => 'my_zone',
         })
       end
 
       it 'should configure bdd driver in cinder.conf' do
         should contain_cinder_config('hippo/available_devices').with_value('/dev/sdb,/dev/sdc')
         should contain_cinder_config('hippo/volumes_dir').with_value('/var/lib/cinder/bdd-volumes')
-        should contain_cinder_config('hippo/iscsi_ip_address').with_value('10.20.0.2')
-        should contain_cinder_config('hippo/iscsi_helper').with_value('lioadm')
+        should contain_cinder_config('hippo/target_ip_address').with_value('10.20.0.2')
+        should contain_cinder_config('hippo/target_helper').with_value('lioadm')
         should contain_cinder_config('hippo/volume_group').with_value('cinder')
         should contain_cinder_config('hippo/volume_clear').with_value('zero')
+        should contain_cinder_config('hippo/backend_availability_zone').with_value('my_zone')
+      end
+      it 'should create type with properties' do
+        should contain_cinder_type('hippo').with(:ensure => :present, :properties => ['volume_backend_name=hippo'])
       end
     end
 
@@ -58,6 +65,27 @@ describe 'cinder::backend::bdd' do
         })
       end
     end
+
+    context 'with deprecated iscsi_ip_address' do
+      before do
+        params.merge!({
+          :target_ip_address => :undef,
+          :iscsi_ip_address  => '127.0.0.42',
+        })
+      end
+      it 'should configure bdd driver using that address' do
+        should contain_cinder_config('hippo/target_ip_address').with_value('127.0.0.42')
+      end
+    end
+
+    context 'with no target_ip_address or iscsi_ip_address' do
+      before do
+        params.delete(:target_ip_address)
+      end
+      it 'is expected to raise error' do
+        is_expected.to raise_error(Puppet::Error, /A target_ip_address or iscsi_ip_address must be specified./)
+      end
+    end
   end
 
   shared_examples_for 'check needed daemons' do
@@ -70,7 +98,7 @@ describe 'cinder::backend::bdd' do
 
     context 'lioadm helper' do
      before do
-       params.merge!({:iscsi_helper => 'lioadm'})
+       params.merge!({:target_helper => 'lioadm'})
      end
      it 'is expected to have target daemon' do
        is_expected.to contain_package('targetcli').with(:ensure => :present)
@@ -80,10 +108,10 @@ describe 'cinder::backend::bdd' do
 
     context 'wrong helper' do
       before do
-        params.merge!({:iscsi_helper => 'fake'})
+        params.merge!({:target_helper => 'fake'})
       end
       it 'is expected to raise error' do
-        is_expected.to raise_error(Puppet::Error, /Unsupported iscsi helper: fake/)
+        is_expected.to raise_error(Puppet::Error, /Unsupported target helper: fake/)
       end
     end
   end
