@@ -11,6 +11,7 @@ describe 'cinder::backend::glusterfs' do
 
     let :params do
       {
+        :backend_availability_zone  => 'my_zone',
         :glusterfs_shares           => ['10.10.10.10:/volumes', '10.10.10.11:/volumes'],
         :glusterfs_shares_config    => '/etc/cinder/other_shares.conf',
         :glusterfs_sparsed_volumes  => true,
@@ -21,6 +22,8 @@ describe 'cinder::backend::glusterfs' do
     it 'configures glusterfs volume driver' do
       is_expected.to contain_cinder_config('mygluster/volume_driver').with_value(
         'cinder.volume.drivers.glusterfs.GlusterfsDriver')
+      is_expected.to contain_cinder_config('mygluster/backend_availability_zone').with_value(
+        'my_zone')
       is_expected.to contain_cinder_config('mygluster/glusterfs_backup_mount_point').with_value(
         '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('mygluster/glusterfs_backup_share').with_value(
@@ -33,8 +36,8 @@ describe 'cinder::backend::glusterfs' do
         '/cinder_mount_point')
       is_expected.to contain_file('/etc/cinder/other_shares.conf').with(
         :content => "10.10.10.10:/volumes\n10.10.10.11:/volumes\n",
-        :require => 'Package[cinder]',
-        :notify  => 'Service[cinder-volume]'
+        :require => 'Anchor[cinder::install::end]',
+        :notify  => 'Anchor[cinder::service::begin]'
       )
     end
 
@@ -66,7 +69,7 @@ describe 'cinder::backend::glusterfs' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+        facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
       it_configures 'glusterfs volume driver'
