@@ -6,6 +6,7 @@ describe 'cinder::backend::nfs' do
 
   let :params do
     {
+      :backend_availability_zone   => 'my_zone',
       :nfs_servers                 => ['10.10.10.10:/shares', '10.10.10.10:/shares2'],
       :nfs_mount_attempts          => '4',
       :nfs_mount_options           => 'vers=3',
@@ -18,6 +19,7 @@ describe 'cinder::backend::nfs' do
       :nas_secure_file_operations  => 'auto',
       :nas_secure_file_permissions => 'false',
       :nfs_snapshot_support        => 'true',
+      :nfs_qcow2_volumes           => 'true',
     }
   end
 
@@ -26,6 +28,8 @@ describe 'cinder::backend::nfs' do
     it 'configures nfs volume driver' do
       is_expected.to contain_cinder_config('hippo/volume_backend_name').with(
         :value => 'hippo')
+      is_expected.to contain_cinder_config('hippo/backend_availability_zone').with_value(
+        'my_zone')
       is_expected.to contain_cinder_config('hippo/volume_driver').with_value(
         'cinder.volume.drivers.nfs.NfsDriver')
       is_expected.to contain_cinder_config('hippo/nfs_shares_config').with_value(
@@ -50,6 +54,8 @@ describe 'cinder::backend::nfs' do
         'false')
       is_expected.to contain_cinder_config('hippo/nfs_snapshot_support').with_value(
         'true')
+      is_expected.to contain_cinder_config('hippo/nfs_qcow2_volumes').with_value(
+        'true')
       is_expected.to contain_file('/etc/cinder/other_shares.conf').with(
         :content => "10.10.10.10:/shares\n10.10.10.10:/shares2",
         :require => 'Anchor[cinder::install::end]',
