@@ -13,7 +13,10 @@ describe 'cinder::backend::nvmeof' do
   end
 
   let :facts do
-    OSDefaults.get_facts({:osfamily => 'Debian'})
+    OSDefaults.get_facts({
+      :osfamily => 'Debian',
+      :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
+    })
   end
 
   let :params do
@@ -37,9 +40,24 @@ describe 'cinder::backend::nvmeof' do
         :value => '10')
       is_expected.to contain_cinder_config('nvme-backend/volume_backend_name').with(
         :value => 'nvme-backend')
+      is_expected.to contain_cinder_config('nvme-backend/backend_availability_zone').with(
+        :value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('nvme-backend/volume_driver').with(
         :value => 'cinder.volume.drivers.lvm.LVMVolumeDriver')
     end
+
+    it { is_expected.to contain_package('nvmetcli').with(
+      :name   => 'nvmetcli',
+      :ensure => 'present',
+      :tag    => 'cinder-support-package',
+    ) }
+
+    it { is_expected.to contain_package('nvme-cli').with(
+      :name   => 'nvme-cli',
+      :ensure => 'present',
+      :tag    => 'cinder-support-package',
+    ) }
+
   end
 
 end
